Request

Struct Request 

pub struct Request<'a, T, M>
where T: Transport<M> + 'a, M: MethodDef,
{ /* private fields */ }

Implementations

Source

impl<'a, T, M> Request<'a, T, M>
where T: Transport<M>, M: MethodDef,

pub fn new(transport: &'a T, input: &'a M::Input) -> Self

pub fn header<K, V>(&mut self, key: K, value: V) -> &mut Self

Append a header to existing headers.

use ntex::http::{header, Request, Response};

fn index(req: Request) -> Response {
    Response::Ok()
        .header("X-TEST", "value")
        .header(header::CONTENT_TYPE, "application/json")
        .finish()
}
pub fn timeout<U>(&mut self, timeout: U) -> &mut Self
where Duration: From<U>,

Set the max duration the request is allowed to take.

The duration will be formatted according to the spec and use the most precise possible.

pub async fn send(self) -> Result<Response<M>, T::Error>

Send request