pub struct GrpcService<T> { /* private fields */ }Trait Implementations
Sourceimpl<T, F> Service<Io<F>> for GrpcService<T>where
F: Filter,
T: ServiceFactory<ServerRequest, SharedCfg, Response = ServerResponse, Error = ServerError> + 'static,
impl<T, F> Service<Io<F>> for GrpcService<T>where
F: Filter,
T: ServiceFactory<ServerRequest, SharedCfg, Response = ServerResponse, Error = ServerError> + 'static,
Sourcetype Error = <T as ServiceFactory<ServerRequest, SharedCfg>>::InitError
type Error = <T as ServiceFactory<ServerRequest, SharedCfg>>::InitError
Errors produced by the service when polling readiness or executing call.
Sourceasync fn call(
&self,
io: Io<F>,
_: ServiceCtx<'_, Self>,
) -> Result<(), Self::Error>
async fn call( &self, io: Io<F>, _: ServiceCtx<'_, Self>, ) -> Result<(), Self::Error>
Processes a request and returns the response asynchronously. Read more
Sourceasync fn ready(&self, ctx: ServiceCtx<'_, Self>) -> Result<(), Self::Error>
async fn ready(&self, ctx: ServiceCtx<'_, Self>) -> Result<(), Self::Error>
Returns when the service is ready to process requests. Read more
Sourcefn poll(&self, cx: &mut Context<'_>) -> Result<(), Self::Error>
fn poll(&self, cx: &mut Context<'_>) -> Result<(), Self::Error>
Polls the service from the current async task. Read more
Sourceimpl<T> Service<IoBoxed> for GrpcService<T>where
T: ServiceFactory<ServerRequest, SharedCfg, Response = ServerResponse, Error = ServerError> + 'static,
impl<T> Service<IoBoxed> for GrpcService<T>where
T: ServiceFactory<ServerRequest, SharedCfg, Response = ServerResponse, Error = ServerError> + 'static,
Sourcetype Error = <T as ServiceFactory<ServerRequest, SharedCfg>>::InitError
type Error = <T as ServiceFactory<ServerRequest, SharedCfg>>::InitError
Errors produced by the service when polling readiness or executing call.
Sourceasync fn call(
&self,
io: IoBoxed,
_: ServiceCtx<'_, Self>,
) -> Result<(), Self::Error>
async fn call( &self, io: IoBoxed, _: ServiceCtx<'_, Self>, ) -> Result<(), Self::Error>
Processes a request and returns the response asynchronously. Read more
Sourceasync fn ready(&self, ctx: ServiceCtx<'_, Self>) -> Result<(), Self::Error>
async fn ready(&self, ctx: ServiceCtx<'_, Self>) -> Result<(), Self::Error>
Returns when the service is ready to process requests. Read more
Sourcefn poll(&self, cx: &mut Context<'_>) -> Result<(), Self::Error>
fn poll(&self, cx: &mut Context<'_>) -> Result<(), Self::Error>
Polls the service from the current async task. Read more